#include "wiced.h"

static wiced_result_t timed_event(void* arg);

static wiced_worker_thread_t event_worker_thread;
static wiced_timed_event_t timed_event_handle;

void application_start(void) {
	WPRINT_APP_INFO(("Starting WICED\n"));
	wiced_init();

	WPRINT_APP_INFO(("Connecting WIFI\n"));
	wiced_network_up( WICED_STA_INTERFACE, WICED_USE_EXTERNAL_DHCP_SERVER, NULL );

	WPRINT_APP_INFO(("Enable MCU powersave\n"));
	wiced_platform_mcu_enable_powersave();

	WPRINT_APP_INFO(("Create thread and timed event\n"));
	wiced_rtos_create_worker_thread(&event_worker_thread, WICED_NETWORK_WORKER_PRIORITY, (10 * 1024), 1);
	wiced_rtos_register_timed_event(&timed_event_handle, &event_worker_thread, timed_event, 60 * 1000, NULL);

	WPRINT_APP_INFO(("Running\n"));
}

static wiced_result_t timed_event(void* arg) {
	wiced_utc_time_ms_t utc_time_ms;
	wiced_iso8601_time_t iso8601_time;

	wiced_time_get_utc_time_ms(&utc_time_ms);
	wiced_time_convert_utc_ms_to_iso8601(utc_time_ms, &iso8601_time);

	WPRINT_APP_INFO(("Time: %.26s\n", (char*)&iso8601_time));

	wiced_ip_address_t address;
	wiced_hostname_lookup("www.google.com", &address, 30000);

	return WICED_SUCCESS;
}

